#
# spec file for package python-zope.event
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global modname zope.event
%{?sle15_python_module_pythons}
Name:           python-zope.event
Version:        5.0
Release:        2.2
Summary:        Very basic event publishing system
License:        ZPL-2.1
URL:            https://pypi.python.org/pypi/%{modname}
Source:         https://files.pythonhosted.org/packages/source/z/zope.event/%{modname}-%{version}.tar.gz
# fix upstream, compatible with recent Sphinx
Patch1:         intersphinx.patch
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
# Documentation requirements:
BuildRequires:  python3-Sphinx
BuildArch:      noarch
%python_subpackages

%description
An event publishing system and a very simple event-dispatching system on
which more sophisticated event dispatching systems can be built. For
example, a type-based event dispatching system that builds on zope.event
can be found in zope.component.

%package -n %{name}-doc
Summary:        Very basic event publishing system

%description -n %{name}-doc
This package contains documentation files for %{name}.

%prep
%setup -q -n %{modname}-%{version}
%autopatch -p1

%build
%python_build
# cannot give build/lib here, as pkg_resources.py needs the egg info and
# raises DistributionNotFound for zope.event, hence build doc directly
# from source in order to avoid the need for an external doc package
export PYTHONPATH=$(pwd)/src
sphinx-build -b html docs build/sphinx/html && rm -r build/sphinx/html/.{buildinfo,doctrees}

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
cd build/lib
%{python_expand \
$python -m unittest -v zope.event.tests
$python -m doctest -v zope/event/classhandler.py
}

%files %{python_files}
%license COPYRIGHT.txt LICENSE.txt
%doc CHANGES.rst README.rst
%{python_sitelib}/*

%if 0%{?suse_version} > 1500
%files -n %{name}-doc
%endif
%doc build/sphinx/html/

%changelog
* Thu Sep  5 2024 Christoph G <foss@grueninger.de>
- Add patch intersphinx.patch for compatibility with recent
  version of Sphinx
* Thu Sep  7 2023 Dirk Müller <dmueller@suse.com>
- update to 5.0:
  * Drop support for Python 2.7, 3.5, 3.6.
* Wed Jul 26 2023 Bernhard Wiedemann <bwiedemann@suse.com>
- Drop sphinx doctrees for reproducible builds
* Tue May 30 2023 Daniel Garcia <daniel.garcia@suse.com>
- Switch documentation to be within the main package.
* Wed May  3 2023 Martin Liška <mliska@suse.cz>
- Use sphinx-build and do not depend on removed build_sphinx
  in Sphinx 7.0 (boo#1211051).
* Fri Apr 21 2023 Dirk Müller <dmueller@suse.com>
- add sle15_python_module_pythons (jsc#PED-68)
* Thu Apr 13 2023 Matej Cepl <mcepl@suse.com>
- Make calling of %%{sle15modernpython} optional.
* Fri Feb 10 2023 Dirk Müller <dmueller@suse.com>
- update to 4.6:
  * Port documentation to Python 3.
  * Add support for Python 3.10, 3.11.
* Fri Sep 24 2021 pgajdos@suse.com
- %%check: do not use setup.py test
* Fri Jul  9 2021 Jason Craig <os@jacraig.com>
- Update to 4.5.0
  * Add support for Python 3.8 and 3.9.
  * Remove support for Python 3.4.
* Wed Apr  8 2020 Tomáš Chvátal <tchvatal@suse.com>
- Do not pull in py2 package on doc subpkg
* Fri Apr  5 2019 Marketa Calabkova <mcalabkova@suse.com>
- update to version 4.4
  * Add support for Python 3.6 and 3.7.
  * Drop support for Python 3.3.
* Thu Dec  6 2018 Tomáš Chvátal <tchvatal@suse.com>
- Fix fdupes call
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Wed Jun 21 2017 jmatejek@suse.com
- use only python3-Sphinx for doc build
- drop %%sitelib redefinition which makes no sense with python-rpm-macros
* Sat Jun 17 2017 okurz@suse.com
- Update to 4.2.0:
  * Add support for Python 3.5.
  * Drop support for Python 2.6 and 3.2.
- Prevent duplicate doc package generation
- Cleanup duplicates in build tree
* Sat Jun 17 2017 okurz@suse.com
- Update to 4.1.0:
  * Require 100%% branch (as well as statement) coverage.
  * Add a simple class-based handler implementation.
* Sat Mar 11 2017 okurz@suse.com
- Convert package to singlespec
* Fri May 15 2015 benoit.monin@gmx.fr
- update to version 4.0.3:
  * Added support for Python 3.4.
  * Updated boostrap.py to version 2.2.
- obsolete previous versions of python-zope-event, not current
- rename CHANGES.txt to CHANGES.rst: changed upstream
- rename README.txt to README.rst: changed upstream
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Tue Jul 30 2013 hpj@urpla.net
- spell out upstream URL in Source:
* Mon Jul 29 2013 hpj@urpla.net
- generate documantation in separate -doc package
- replace bz2 tarball with original gz without trailing garbarge
* Fri Mar 15 2013 speilicke@suse.com
- Rename to python-zope.event to match usptream name
* Tue Jan 15 2013 saschpe@suse.de
- Drop the lib dir messing around, the package is noarch
* Mon Jan 14 2013 p.drouand@gmail.com
- Initial python3 support
* Mon Jan 14 2013 p.drouand@gmail.com
- Update to 4.0.2 version:
  * Fleshed out PyPI Trove classifiers.
  * Added support for jython 2.7.
* Tue Jan 24 2012 coolo@suse.com
- remove use of %%suse_update_libdir
* Wed Jan 18 2012 cdenicolo@suse.com
- license update: ZPL-2.1
  is ZPL-2-1
* Thu Jan 12 2012 coolo@suse.com
- change license to be in spdx.org format
* Wed Nov 10 2010 coolo@novell.com
- fix file list
* Thu Sep 16 2010 coolo@novell.com
- fix build on distributions != 11.3
* Fri Jun 25 2010 hvogel@novell.com
- Ugly hack to make this an arch package. Apparently it does not
  work to have bundled modules spread over lib/lib64
* Tue Jun 22 2010 hvogel@novell.com
- get rid of buildroot removal in install
* Wed Jun  2 2010 hvogel@novell.com
- Initial Package, Version 3.5.0
